@@ -3,7 +3,7 @@ BEGIN {
   $POE::Component::FeedAggregator::AUTHORITY = 'cpan:GETTY';
 }
 BEGIN {
-  $POE::Component::FeedAggregator::VERSION = '0.900';
+  $POE::Component::FeedAggregator::VERSION = '0.901';
 }
 # ABSTRACT: Watch multiple feeds (Atom or RSS) for new headlines 
 
@@ -17,15 +17,37 @@ use IO::All;
 
 our $VERSION ||= '0.0development';
 
+has logger => (
+	isa => 'Object',
+	is => 'rw',
+	predicate => 'has_logger',
+);
+
+has http_agent => (
+	is => 'ro',
+	isa => 'Str',
+	required => 1,
+	default => sub { __PACKAGE__.'/'.$VERSION },
+);
+
 has feed_client => (
 	isa => 'POE::Component::Client::Feed',
 	is => 'ro',
 	lazy => 1,
 	required => 1,
 	default => sub {
-		POE::Component::Client::Feed->new({
-			http_agent => __PACKAGE__.'/'.$VERSION,
-		});
+		my $self = shift;
+		$self->logger->info($self->logger_prefix.'Starting up POE::Component::Client::Feed') if $self->has_logger;
+		if ($self->has_logger) {
+			POE::Component::Client::Feed->new({
+				http_agent => $self->http_agent,
+				logger   => $self->logger,
+			});
+		} else {
+			POE::Component::Client::Feed->new({
+				http_agent => $self->http_agent,
+			});
+		}
 	},
 );
 
@@ -38,8 +60,10 @@ has tmpdir => (
 
 event feed_received => sub {
 	my ( $self, $kernel, @args ) = @_[ OBJECT, KERNEL, ARG0..$#_ ];
+	$self->logger->debug($self->logger_prefix.'Feed received') if $self->has_logger;
 	my $http_request = $args[0];
 	my $feed = $args[2];
+	$self->logger->debug($self->logger_prefix.'Request feed '.$feed->url.' delayed with '.$feed->delay.' seconds') if $self->has_logger;
 	$kernel->delay( 'request_feed', $feed->delay, $feed );
 	my $xml_feed = $args[1];
 	return if !(ref $xml_feed);
@@ -52,6 +76,7 @@ event feed_received => sub {
 		$ignore = $feed->ignore_first;
 	}
 	my @new_entries;
+	$self->logger->debug($self->logger_prefix.( scalar $xml_feed->entries ).' Entries found') if $self->has_logger;
 	for my $entry ($xml_feed->entries) {
 		my $link = $entry->link;
 		my $title = $entry->title;
@@ -70,14 +95,17 @@ event feed_received => sub {
 		push @new_entries, $link.' '.$title;
 		$kernel->post( $feed->sender, $feed->entry_event, $feed, $entry ) if (!$known and !$ignore);
 	}
+	$self->logger->debug($self->logger_prefix.( scalar @new_entries ).' new entries') if $self->has_logger;
 	push @entries, @new_entries;
 	my $count = @entries;
 	my @save_entries = splice(@entries, $count - $feed->max_headlines > 0 ? $count - $feed->max_headlines : 0, $feed->max_headlines);
+	$self->logger->debug($self->logger_prefix.'Saving cache file '.$cache_file) if $self->has_logger;
 	scalar join("\n",@save_entries) > io($cache_file);
 };
 
 event request_feed => sub {
 	my ( $self, $feed ) = @_[ OBJECT, ARG0..$#_ ];
+	$self->logger->debug($self->logger_prefix.'Requesting feed '.$feed->url) if $self->has_logger;
 	$self->feed_client->yield('request',$feed->url,'feed_received',$feed);
 };
 
@@ -87,9 +115,15 @@ event _add_feed => sub {
 	my ( $self, $sender, $feed_args ) = @_[ OBJECT, SENDER, ARG0..$#_ ];
 	$feed_args->{sender} = $sender;
 	my $feed = POE::Component::FeedAggregator::Feed->new($feed_args);
+	$self->logger->debug($self->logger_prefix.'Added feed '.$feed->url) if $self->has_logger;
 	$self->yield( request_feed => $feed );
 };
 
+sub logger_prefix {
+	my $self = shift;
+	__PACKAGE__.' ('.$self->get_session_id.') ';
+}
+
 1;
 
 
@@ -102,7 +136,7 @@ POE::Component::FeedAggregator - Watch multiple feeds (Atom or RSS) for new head
 
 =head1 VERSION
 
-version 0.900
+version 0.901
 
 =head1 SYNOPSIS
 
